@@ -24,16 +24,16 @@ class TagProcedure extends BaseProcedure
         return $this->tagModel->getAllByProject($project_id);
     }
 
-    public function createTag($project_id, $tag)
+    public function createTag($project_id, $tag, $color_id = null)
     {
         ProjectAuthorization::getInstance($this->container)->check($this->getClassName(), 'createTag', $project_id);
-        return $this->tagModel->findOrCreateTag($project_id, $tag);
+        return $this->tagModel->create($project_id, $tag, $color_id);
     }
 
-    public function updateTag($tag_id, $tag)
+    public function updateTag($tag_id, $tag, $color_id = null)
     {
         TagAuthorization::getInstance($this->container)->check($this->getClassName(), 'updateTag', $tag_id);
-        return $this->tagModel->update($tag_id, $tag);
+        return $this->tagModel->update($tag_id, $tag, $color_id);
     }
 
     public function removeTag($tag_id)
