@@ -21,8 +21,9 @@ class WorkerCommand extends BaseCommand
         ;
     }
 
-    protected function execute(InputInterface $input, OutputInterface $output)
+    protected function execute(InputInterface $input, OutputInterface $output): int
     {
         $this->queueManager->listen();
+        return 0;
     }
 }
