@@ -324,12 +324,15 @@ abstract class BaseController extends Base
      */
     protected function redirectAfterLogin()
     {
-        if (session_exists('redirectAfterLogin') && ! filter_var(session_get('redirectAfterLogin'), FILTER_VALIDATE_URL)) {
-            $redirect = session_get('redirectAfterLogin');
+        $redirectUri = $this->helper->url->to('DashboardController', 'show');
+
+        if (session_exists('redirectAfterLogin')) {
+            if ($this->request->isSafeRedirectUri(session_get('redirectAfterLogin'))) {
+                $redirectUri = session_get('redirectAfterLogin');
+            }
             session_remove('redirectAfterLogin');
-            $this->response->redirect($redirect);
-        } else {
-            $this->response->redirect($this->helper->url->to('DashboardController', 'show'));
         }
+
+        $this->response->redirect($redirectUri);
     }
 }
