@@ -923,7 +923,6 @@ return [
     'Auto' => 'Auto',
     'Related' => 'Liittyvät',
     'Attachment' => 'Liite',
-    'Title not found' => 'Otsikkoa ei löydy',
     'Web Link' => 'Web-linkki',
     'External links' => 'Ulkoiset linkit',
     'Add external link' => 'Lisää ulkoinen linkki',
@@ -1468,6 +1467,6 @@ return [
     'Add attachments' => 'Lisää liitteitä',
     'Task #%d "%s" is overdue' => 'Tehtävä #%d "%s" on myöhässä',
     'Enable notifications by default for all new users' => 'Ota ilmoitukset käyttöön oletuksena kaikille uusille käyttäjille',
-    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
-    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Määritä tehtävä sen luojalle tietyissä sarakkeissa, jos vastuuhenkilöä ei ole asetettu manuaalisesti',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Määritä tehtävä kirjautuneelle käyttäjälle siirrettäessä määritettyyn sarakkeeseen, jos käyttäjää ei ole määritetty',
 ];
