@@ -923,7 +923,6 @@ return [
     'Auto' => '자동',
     'Related' => '연관된',
     'Attachment' => '첨부',
-    'Title not found' => '제목이 없습니다',
     'Web Link' => '웹 링크',
     'External links' => '외부 링크',
     'Add external link' => '외부 링크 추가',
@@ -1468,6 +1467,6 @@ return [
     'Add attachments' => '첨부 파일 추가',
     'Task #%d "%s" is overdue' => '할일 #%d "%s"의 기한이 지났습니다',
     'Enable notifications by default for all new users' => '모든 신규 사용자에 대해 기본적으로 알림 활성화',
-    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
-    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => '담당자가 수동으로 지정되지 않은 경우, 지정한 컬럼에서는 작업을 생성자에게 할당',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => '사용자가 할당되지 않은 경우, 컬럼 변경으로 지정된 컬럼으로 이동할 때 작업을 로그인한 사용자에게 할당',
 ];
