@@ -923,7 +923,6 @@ return [
     'Auto' => 'Auto',
     'Related' => 'Relasjon',
     'Attachment' => 'Vedlegg',
-    'Title not found' => 'Finner ingen tittel',
     'Web Link' => 'Web-lenke',
     'External links' => 'Eksterne lenker',
     'Add external link' => 'Ny ekstern lenke',
@@ -1468,6 +1467,6 @@ return [
     'Add attachments' => 'Legg til vedlegg',
     'Task #%d "%s" is overdue' => 'Oppgaven #%d "%s" er forsinket',
     'Enable notifications by default for all new users' => 'Aktiver varslinger som standard for alle nye brukere',
-    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
-    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Tilordne oppgaven til dens oppretter for bestemte kolonner hvis ingen ansvarlig er satt manuelt',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Tilordne en oppgave til innlogget bruker ved kolonneendring til angitt kolonne hvis ingen bruker er tilordnet',
 ];
