@@ -923,7 +923,6 @@ return [
     'Auto' => 'Auto',
     'Related' => 'Relacionado',
     'Attachment' => 'Anexo',
-    'Title not found' => 'Titulo não encontrado',
     'Web Link' => 'Ligação Web',
     'External links' => 'Ligações externas',
     'Add external link' => 'Adicionar ligação externa',
@@ -1468,6 +1467,6 @@ return [
     'Add attachments' => 'Adicionar anexos',
     'Task #%d "%s" is overdue' => 'Tarefa #%d "%s" está atrasada',
     'Enable notifications by default for all new users' => 'Ativar notificações por padrão para todos os novos usuários',
-    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
-    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Atribuir a tarefa ao seu criador para colunas específicas se nenhum responsável for definido manualmente',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Atribuir a tarefa ao utilizador com sessão iniciada ao mudar de coluna para a coluna especificada se nenhum utilizador estiver atribuído',
 ];
