@@ -923,7 +923,6 @@ return [
     'Auto' => 'Auto',
     'Related' => 'Asociat',
     'Attachment' => 'Atașament',
-    'Title not found' => 'Titlul nu a fost găsit',
     'Web Link' => 'Link web',
     'External links' => 'Legături externe',
     'Add external link' => 'Adaugă legătură externă',
@@ -1468,6 +1467,6 @@ return [
     'Add attachments' => 'Adaugă atașamente',
     'Task #%d "%s" is overdue' => 'Sarcina #%d "%s" este întârziată',
     'Enable notifications by default for all new users' => 'Activează notificările implicit pentru toți utilizatorii noi',
-    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
-    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Atribuie sarcina creatorului ei pentru coloane specifice dacă nu este setat manual niciun responsabil',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Atribuie sarcina utilizatorului autentificat la schimbarea coloanei către coloana specificată dacă nu este atribuit niciun utilizator',
 ];
