@@ -923,7 +923,6 @@ return [
     'Auto' => 'Automatski',
     'Related' => 'Povezan',
     'Attachment' => 'Priložak',
-    'Title not found' => 'Bez naslova',
     'Web Link' => 'Veb link',
     'External links' => 'Spoljne veze',
     'Add external link' => 'Dodaj spoljnu vezu',
@@ -1468,4 +1467,6 @@ return [
     'Add attachments' => 'Dodaj priloge',
     'Task #%d "%s" is overdue' => 'Zadatak #%d "%s" je s iztečen rok',
     'Enable notifications by default for all new users' => 'Omogući notifikacije po difoltu za sve nove korisnike',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Dodeli zadatak njegovom kreatoru za određene kolone ako izvršilac nije ručno postavljen',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Dodeli zadatak prijavljenom korisniku pri promeni kolone u zadatu kolonu ako niko nije dodeljen',
 ];
