@@ -923,7 +923,6 @@ return [
     'Auto' => '自動',
     'Related' => '相關的',
     'Attachment' => '附件',
-    'Title not found' => '標題未找到',
     'Web Link' => '網頁連結',
     'External links' => '外部連結',
     'Add external link' => '增加外部連結',
@@ -1468,6 +1467,6 @@ return [
     'Add attachments' => '加入附件',
     'Task #%d "%s" is overdue' => '任務 #%d "%s" 已逾期',
     'Enable notifications by default for all new users' => '預設啟用所有新使用者的通知',
-    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
-    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => '若未手動指定負責人，則在指定欄位中將任務指派給建立者',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => '若未指派使用者，則在變更欄位移動到指定欄位時將任務指派給已登入使用者',
 ];
